@@ -1,19 +1,19 @@
 package Box::Calc::Item;
-BEGIN {
-  $Box::Calc::Item::VERSION = '0.0501';
-}
-
+$Box::Calc::Item::VERSION = '1.0000';
 use strict;
 use warnings;
 use Moose;
 
+with 'Box::Calc::Role::Dimensional';
+
+
 =head1 NAME
 
 Box::Calc::Item - The container class for the items you wish to pack.
 
 =head1 VERSION
 
-version 0.0501
+version 1.0000
 
 =head1 SYNOPSIS
 
@@ -51,52 +51,45 @@ The weight of your item.
 
 The name of your item. If you're referring it back to an external system you may wish to use this field to store you item ids instead of item names.
 
-=item quantity
-
-Defaults to 1. The number of copies of this item that need to be packed.
-
 =back
 
 =back
 
+
+=head2 name
+
+Returns the name of this item.
+
 =cut
 
-has quantity => (
-    is          => 'ro',
-    default     => 1,
-    isa         => 'Num',
-);
-
-has x => (
-    is          => 'ro',
-    required    => 1,
-    isa         => 'Num',
-);
-
-has y => (
-    is          => 'ro',
-    required    => 1,
-    isa         => 'Num',
-);
-
-has z => (
-    is          => 'ro',
-    required    => 1,
-    isa         => 'Num',
-);
-
-has weight => (
-    is          => 'ro',
-    isa         => 'Num',
-    required    => 1,
-);
-
 has name => (
     is          => 'ro',
     isa         => 'Str',
     required    => 1,
 );
 
+=head2 describe
+
+Returns all the important details about this item as a hash reference.
+
+=cut
+
+sub describe {
+    my $self = shift;
+    return {
+        name    => $self->name,
+        weight  => $self->weight,
+        x       => $self->x,
+        y       => $self->y,
+        z       => $self->z,
+    };
+}
+
+=head1 ROLES
+
+This class installs L<Box::Calc::Role::Dimensional>.
+
+=cut
 
 no Moose;
-__PACKAGE__->meta->make_immutable;
\ No newline at end of file
+__PACKAGE__->meta->make_immutable;
