@@ -1,12 +1,11 @@
 package Box::Calc::Layer;
-BEGIN {
-  $Box::Calc::Layer::VERSION = '0.0200';
-}
-
+$Box::Calc::Layer::VERSION = '1.0000';
 use strict;
 use Moose;
 use Box::Calc::Row;
-use Ouch;
+use List::Util qw/sum/;
+use Log::Any qw($log);
+use Data::Dumper;
 
 =head1 NAME
 
@@ -14,7 +13,7 @@ Box::Calc::Layer - A box is packed with multiple layers.
 
 =head1 VERSION
 
-version 0.0200
+version 1.0000
 
 =head1 SYNOPSIS
 
@@ -52,7 +51,7 @@ sub fill_x {
     foreach my $row (@{$self->rows}) {
         $value = $row->fill_x if $row->fill_x > $value;
     }
-    return $value;
+    return sprintf ("%.4f", $value);
 }
 
 =head2 fill_y()
@@ -67,7 +66,7 @@ sub fill_y {
     foreach my $row (@{$self->rows}) {
         $value += $row->fill_y;
     }
-    return $value;
+    return sprintf ("%.4f", $value);
 }
 
 =head2 fill_z()
@@ -82,7 +81,7 @@ sub fill_z {
     foreach my $row (@{$self->rows}) {
         $value = $row->fill_z if $row->fill_z > $value;
     }
-    return $value;
+    return sprintf ("%.4f", $value);
 }
 
 =head2 max_x()
@@ -164,6 +163,8 @@ sub calculate_weight {
 
 Add a L<Box::Calc::Item> to this layer.
 
+Returns 1 on success or 0 on failure.
+
 =over
 
 =item item
@@ -175,33 +176,85 @@ The L<Box::Calc::Item> instance you want to add to this layer.
 =cut
 
 sub pack_item {
-    my ($self, $item) = @_;
-    eval { $self->rows->[-1]->pack_item($item) };
-    if (kiss 'x too big') {
-        my $remaining_y = $self->max_y - $self->fill_y;
-        if ($item->y > $remaining_y) {
-            ouch 'y too big', 'Item too big for this layer.'; 
+    my ($self, $item, $count) = @_;
+    $count ||= 1;
+    if ($count > 99) {
+        $log->warn($item->{name}.' is causing infinite recursion in Box::Calc::Layer');
+        $log->debug(Dumper($item));
+        return 0;
+    }
+    my $fill_z = $self->fill_z;
+    my $fill_y = $self->fill_y;
+    if ($item->y > $self->max_y - $fill_y + $self->rows->[-1]->fill_y # item would make the layer too wide
+        ) {
+        $log->info($item->{name}.' would make the layer too wide, requesting new layer.');
+        return 0;
+    }
+    if ($fill_z > 0 && $item->z > $fill_z * 1.75 && $item->y < $fill_y) { # item would make the layer substantially taller, unless the layer is currently pretty narrow
+        $log->info($item->{name}.' would make this layer substantially taller, requesting new layer.');
+        return 0;
+    }
+    if ($self->rows->[-1]->pack_item($item)) {
+        return 1;
+    }
+    else {
+        if ($item->y > $self->max_y - $self->fill_y) {
+            $log->info($item->{name}.' will not fit in a new row in this layer, requesting new layer.');
+            return 0;
         }
         else {
             $self->create_row;
-            $self->pack_item($item);
+            return $self->pack_item($item, $count + 1);
         }
     }
 }
 
-=head2 packing_list()
+=head2 packing_list(weight, list)
 
-Returns an array reference of L<Box::Calc::Row> packing lists.
+Updates a scalar reference with the weight of the layer and a hash reference of all the items in this layer.
 
 =cut
 
 sub packing_list {
+    my ($self, $weight, $list) = @_;
+    foreach my $row (@{$self->rows}) {
+        $row->packing_list($weight, $list)
+    }
+}
+
+=head2 packing_instructions()
+
+Returns a description of the layer.
+
+{
+ fill_x => 3,
+ fill_y => 3,
+ fill_z => 1,
+ rows => [ ... ],
+}
+
+=cut
+
+sub packing_instructions {
     my $self = shift;
-    my @rows = map { $_->packing_list } @{ $self->rows };
-    return \@rows;
+    return {
+        rows                => [  map { $_->packing_instructions } @{ $self->rows } ],
+        fill_x              => $self->fill_x,
+        fill_y              => $self->fill_y,
+        fill_z              => $self->fill_z,
+        calculated_weight   => $self->calculate_weight,
+    }
+}
+
+sub used_volume {
+    my $self = shift;
+    return sum map { $_->used_volume } @{ $self->rows };
 }
 
 
+sub volume {
+    return $_[0]->fill_x * $_[0]->fill_y * $_[0]->fill_z;
+}
 
 no Moose;
-__PACKAGE__->meta->make_immutable;
\ No newline at end of file
+__PACKAGE__->meta->make_immutable;
